@@ -17,5 +17,5 @@ class OpenFlask:
     def run(self, host='0.0.0.0', port=8080, debug=False):
         self.app.run(host, port, debug)
 
-app = OpenFlask('app', {}, {})
-app.run()
+#app = OpenFlask('app')
+#app.run()
